{% load wagtailroutablepage_tags puput_tags %}
<header>
    <h2 class="post_title">
        <a href="{% entry_url entry blog_page %}">{{ entry.title }}</a>
    </h2>
    <ul class="links">
        <li>
            <i class="fa fa-user"></i>
            <a href="{% routablepageurl blog_page "entries_by_author" entry.owner.username %}">
                {{ entry.owner.username }}
            </a>
        </li>
        <li>
            <i class="fa fa-calendar"></i>
            {{ entry.date|date:"DATE_FORMAT" }}
        </li>
        {% if entry.categories.count > 0 %}
            <li>
                <i class="fa fa-folder-open"></i>
                {% categories_list entry.categories %}
            </li>
        {% endif %}
        {% if entry.tags.count > 0 %}
            <li>
                <i class="fa fa-tag"></i>
                {% tags_list blog_page.num_tags_entry_header entry.tags %}
            </li>
        {% endif %}
        {% if blog_page.disqus_api_secret %}
            <li>
                <i class="fa fa-comments"></i>
                {{ entry.num_comments }}
            </li>
        {% endif %}
    </ul>
</header>