{% load static %}

<div id="disqus_thread"></div>
<script type="text/javascript">
    /* <![CDATA[ */
        var disqus_shortname = '{{ disqus_shortname }}';
        var disqus_identifier = '{{ disqus_identifier }}';

        /* * * DON'T EDIT BELOW THIS LINE * * */
        (function() {
            var dsq = document.createElement('script'); dsq.type = 'text/javascript'; dsq.async = true;
            dsq.src = '//' + disqus_shortname + '.disqus.com/embed.js';
            (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(dsq);
        })();
    /* ]]> */
</script>
<noscript>Please enable JavaScript to view the <a href="//disqus.com/?ref_noscript">comments powered by Disqus.</a></noscript>
<a href="//disqus.com" class="dsq-brlink">blog comments powered by <span class="logo-disqus">Disqus</span></a>

{% block extra_js %}
    <script src="{% static 'puput/js/js.cookie.js' %}"></script>
    <script src="{% static 'puput/js/comments/update_entry_comments.js' %}"></script>
    <script src="{% static 'puput/js/comments/disqus.js' %}"></script>
{% endblock extra_js %}
