{% load i18n wagtailroutablepage_tags %}

<ul>
    {% for category in categories %}
        <li>
            <a href="{% routablepageurl blog_page "entries_by_category" category.slug %}">{{ category.name }}</a>
        </li>
    {% empty %}
        {% trans 'No categories yet' %}
    {% endfor %}
</ul>